@@ -20,10 +20,9 @@
  */
 
 #include <stdlib.h>
-#include <libintl.h>
+#include <config.h>
 #include <gnome.h>
 
-#include "config.h"
 #include "seahorse-gpgmex.h"
 #include "seahorse-operation.h"
 #include "seahorse-ldap-source.h"
@@ -440,7 +439,7 @@ seahorse_server_source_new (const gchar *server)
         } else
 #endif /* WITH_HKP */
         
-            g_warning ("unsupported keyserver uri scheme: %s", scheme);
+            g_warning ("unsupported key server uri scheme: %s", scheme);
     }
     
     g_free (uri);
