@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: seahorse-extension.c,v 1.5 2006/10/05 21:03:02 sadam Exp $
+ *  $Id: seahorse-extension.c,v 1.6 2006/11/09 18:15:25 nnielsen Exp $
  */
 
 #include "config.h"
@@ -124,7 +124,7 @@ init_crypt ()
                                                "/org/gnome/seahorse/crypto",
                                                "org.gnome.seahorse.CryptoService");
         
-        dbus_keyset = cryptui_keyset_new ("openpgp");
+        dbus_keyset = cryptui_keyset_new ("openpgp", TRUE);
     }
     
     return TRUE;
