@@ -70,23 +70,23 @@ enum KeyManagerTabs {
 };
 
 SeahorseKeyPredicate pred_public = {
-    0,                  /* ktype, set later */
-    0,                  /* keyid */
-    SKEY_LOC_LOCAL,     /* location */
-    SKEY_PUBLIC,        /* etype */
-    0,                  /* flags */
-    SKEY_FLAG_TRUSTED,  /* nflags */
-    NULL,               /* sksrc */
+    0,                                      /* ktype, set later */
+    0,                                      /* keyid */
+    SKEY_LOC_LOCAL,                         /* location */
+    SKEY_PUBLIC,                            /* etype */
+    0,                                      /* flags */
+    SKEY_FLAG_TRUSTED | SKEY_FLAG_IS_VALID, /* nflags */
+    NULL,                                   /* sksrc */
 };
 
 SeahorseKeyPredicate pred_trusted = {
-    0,                  /* ktype, set later*/
-    0,                  /* keyid */
-    SKEY_LOC_LOCAL,     /* location */
-    SKEY_PUBLIC,        /* etype */
-    SKEY_FLAG_TRUSTED,  /* flags */
-    0,                  /* nflags */
-    NULL,               /* sksrc */
+    0,                                      /* ktype, set later */
+    0,                                      /* keyid */
+    SKEY_LOC_LOCAL,                         /* location */
+    SKEY_PUBLIC,                            /* etype */
+    SKEY_FLAG_TRUSTED | SKEY_FLAG_IS_VALID, /* flags */
+    0,                                      /* nflags */
+    NULL,                                   /* sksrc */
 };
 
 SeahorseKeyPredicate pred_private = {
@@ -334,7 +334,7 @@ set_selected_key (SeahorseWidget *swidget, SeahorseKey *skey)
 }
 
 static void
-set_numbered_status (SeahorseWidget *swidget, const gchar *t1, const gchar *t2, guint num)
+set_numbered_status (SeahorseWidget *swidget, const gchar *message, guint num)
 {
     GtkStatusbar *status;
     guint id;
@@ -346,7 +346,7 @@ set_numbered_status (SeahorseWidget *swidget, const gchar *t1, const gchar *t2,
     id = gtk_statusbar_get_context_id (status, "key-manager");
     gtk_statusbar_pop (status, id);
     
-    msg = g_strdup_printf (ngettext (t1, t2, num), num);
+    msg = g_strdup_printf (message, num);
     gtk_statusbar_push (status, id, msg);
     g_free (msg);
 }
@@ -401,8 +401,8 @@ imported_keys (SeahorseOperation *op, SeahorseWidget *swidget)
     set_selected_keys (swidget, keys);
     
     nkeys = g_list_length (keys);
-    set_numbered_status (swidget, _("Imported %d key"), 
-                                  _("Imported %d keys"), nkeys);
+    set_numbered_status (swidget, ngettext("Imported %d key", 
+            	        	           "Imported %d keys", nkeys), nkeys);
 }
 
 static void
@@ -570,8 +570,8 @@ copy_done (SeahorseOperation *op, SeahorseWidget *swidget)
 
     num = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (op), "num-keys"));
     if (num > 0) {
-        set_numbered_status (swidget, _("Copied %d key"), 
-                                      _("Copied %d keys"), num);
+        set_numbered_status (swidget, ngettext ("Copied %d key", 
+                                                "Copied %d keys", num), num);
     }
 }
 
@@ -640,7 +640,7 @@ export_activate (GtkWidget *widget, SeahorseWidget *swidget)
     if (keys == NULL)
         return;
     
-    dialog = seahorse_util_chooser_save_new (_("Export Key"), 
+    dialog = seahorse_util_chooser_save_new (_("Export public key"), 
                 GTK_WINDOW(glade_xml_get_widget (swidget->xml, "key-manager")));
     seahorse_util_chooser_show_key_files (dialog);
     seahorse_util_chooser_set_filename (dialog, keys);
@@ -681,7 +681,7 @@ backup_activate (GtkWidget *widget, SeahorseWidget *swidget)
     gchar *ext, *t;
     const gchar* home_dir = NULL;
     
-    dialog = seahorse_util_chooser_save_new (_("Back up Keyrings to Archive"), 
+    dialog = seahorse_util_chooser_save_new (_("Back up Key Rings to Archive"), 
                 GTK_WINDOW(glade_xml_get_widget (swidget->xml, "key-manager")));
     seahorse_util_chooser_show_archive_files (dialog);	    	    	    
 
@@ -842,6 +842,7 @@ about_activate (GtkWidget *widget, SeahorseWidget *swidget)
 	static const gchar *documenters[] = {
 		"Jacob Perkins <jap1@users.sourceforge.net>",
         "Adam Schreiber <sadam@clemson.edu>",
+        "Milo Casagrande <milo_casagrande@yahoo.it>",
 		NULL
 	};
 
@@ -941,8 +942,8 @@ selection_changed (GtkTreeSelection *notused, SeahorseWidget *swidget)
     }
     
     if (selected) {
-        set_numbered_status (swidget, _("Selected %d key"),
-                                      _("Selected %d keys"), rows);
+        set_numbered_status (swidget, ngettext ("Selected %d key",
+                                                "Selected %d keys", rows), rows);
         
         keys = get_selected_keys (swidget);
 
@@ -1071,7 +1072,7 @@ tab_changed (GtkWidget *widget, GtkNotebookPage *page, guint page_num,
     
     /* 
      * Because gnome-keyring can throw prompts etc... we delay loading 
-     * of the gnome keyring items until we first access them. 
+     * of the gnome key ring items until we first access them. 
      */
     
 #ifdef WITH_GNOME_KEYRING
@@ -1176,8 +1177,8 @@ static const GtkActionEntry ui_entries[] = {
     { "key-generate", GTK_STOCK_NEW, N_("_Create New Key..."), "<control>N", 
             N_("Create a new personal key"), G_CALLBACK (generate_activate) },
     { "key-import-file", GTK_STOCK_OPEN, N_("_Import..."), "<control>I",
-            N_("Import keys into your keyring from a file"), G_CALLBACK (import_activate) },
-    { "key-backup", GTK_STOCK_SAVE, N_("_Back up Keyrings..."), "",
+            N_("Import keys into your key ring from a file"), G_CALLBACK (import_activate) },
+    { "key-backup", GTK_STOCK_SAVE, N_("_Back up Key Rings..."), "",
             N_("Back up all keys"), G_CALLBACK (backup_activate) }, 
     { "key-import-clipboard", GTK_STOCK_PASTE, N_("Paste _Keys"), "<control>V",
             N_("Import keys from the clipboard"), G_CALLBACK (paste_activate) }, 
@@ -1196,23 +1197,23 @@ static const GtkActionEntry ui_entries[] = {
 };
 
 static const GtkToggleActionEntry view_entries[] = {
-    { "view-type", NULL, N_("Key T_ypes"), NULL,
-             N_("Show key type column"), G_CALLBACK (view_type_column), FALSE },
-    { "view-expires", NULL, N_("Key _Expiry"), NULL,
-             N_("Show key expiry column"), G_CALLBACK (view_expiry_column), FALSE },
-    { "view-trust", NULL, N_("Key _Trust"), NULL,
+    { "view-type", NULL, N_("T_ypes"), NULL,
+             N_("Show type column"), G_CALLBACK (view_type_column), FALSE },
+    { "view-expires", NULL, N_("_Expiry"), NULL,
+             N_("Show expiry column"), G_CALLBACK (view_expiry_column), FALSE },
+    { "view-trust", NULL, N_("_Trust"), NULL,
              N_("Show owner trust column"), G_CALLBACK (view_trust_column), FALSE },
-    { "view-validity", NULL, N_("Key _Validity"), NULL,
-             N_("Show key validity column"), G_CALLBACK (view_validity_column), FALSE },
+    { "view-validity", NULL, N_("_Validity"), NULL,
+             N_("Show validity column"), G_CALLBACK (view_validity_column), FALSE },
 };
 
 static const GtkActionEntry key_entries[] = {
     { "key-properties", GTK_STOCK_PROPERTIES, N_("P_roperties"), NULL,
             N_("Show key properties"), G_CALLBACK (properties_activate) }, 
-    { "key-export-file", GTK_STOCK_SAVE_AS, N_("E_xport..."), NULL,
-            N_("Export public key"), G_CALLBACK (export_activate) }, 
-    { "key-export-clipboard", GTK_STOCK_COPY, N_("_Copy Key"), "<control>C",
-            N_("Copy selected keys to the clipboard"), G_CALLBACK (copy_activate) },
+    { "key-export-file", GTK_STOCK_SAVE_AS, N_("E_xport Public Key..."), NULL,
+            N_("Export public part of key to a file"), G_CALLBACK (export_activate) }, 
+    { "key-export-clipboard", GTK_STOCK_COPY, N_("_Copy Public Key"), "<control>C",
+            N_("Copy public part of selected keys to the clipboard"), G_CALLBACK (copy_activate) },
     { "key-delete", GTK_STOCK_DELETE, N_("_Delete Key"), NULL,
             N_("Delete selected keys"), G_CALLBACK (delete_activate) }, 
 };
@@ -1231,7 +1232,7 @@ static const GtkActionEntry keyserver_entries[] = {
     { "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys..."), "",
             N_("Search for keys on a key server"), G_CALLBACK (search_activate) }, 
     { "remote-sync", GTK_STOCK_REFRESH, N_("_Sync and Publish Keys..."), "",
-            N_("Publish and/or sync your keys with those online."), G_CALLBACK (sync_activate) }, 
+            N_("Publish and/or synchronize your keys with those online."), G_CALLBACK (sync_activate) }, 
 };
 
 void
