@@ -82,11 +82,11 @@ set_status_text (SeahorseWidget *swidget, const gchar *msg)
 }
 
 static void
-set_numbered_status (SeahorseWidget *swidget, const gchar *t1, const gchar *t2, guint num)
+set_numbered_status (SeahorseWidget *swidget, const gchar *message, guint num)
 {
     gchar *msg;
     
-    msg = g_strdup_printf (ngettext (t1, t2, num), num);
+    msg = g_strdup_printf (message, num);
     set_status_text (swidget, msg);
     g_free (msg);
 }
@@ -103,7 +103,7 @@ import_done (SeahorseOperation *op, SeahorseWidget *swidget)
     
     if (!seahorse_operation_is_successful (op)) {
         seahorse_operation_copy_error (op, &err);
-        seahorse_util_handle_error (err, _("Couldn't import keys into keyring"));
+        seahorse_util_handle_error (err, _("Couldn't import keys into key ring"));
     }
 }
 
@@ -230,8 +230,8 @@ copy_done (SeahorseOperation *op, SeahorseWidget *swidget)
 
     num = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (op), "num-keys"));
     if (num > 0) {
-        set_numbered_status (swidget, _("Copied %d key"), 
-                                      _("Copied %d keys"), num);
+        set_numbered_status (swidget, ngettext ("Copied %d key", 
+                                                "Copied %d keys", num), num);
     }
 }
 
@@ -295,8 +295,8 @@ selection_changed (GtkTreeSelection *selection, SeahorseWidget *swidget)
 	rows = gtk_tree_selection_count_selected_rows (selection);
 	
 	if (rows > 0) {
-        set_numbered_status (swidget, _("Selected %d key"), 
-                                      _("Selected %d keys"), rows);
+        set_numbered_status (swidget, ngettext ("Selected %d key", 
+                                                "Selected %d keys", rows), rows);
 	}
 	
     actions = seahorse_widget_find_actions (swidget, "key");
@@ -391,7 +391,7 @@ static const GtkActionEntry ui_entries[] = {
 
 static const GtkActionEntry public_entries[] = {
     { "key-import-keyring", GTK_STOCK_ADD, N_("_Import"), "",
-            N_("Import selected keys to local keyring"), G_CALLBACK (import_activate) },
+            N_("Import selected keys to local key ring"), G_CALLBACK (import_activate) },
     { "key-properties", GTK_STOCK_PROPERTIES, N_("P_roperties"), NULL,
             N_("Show key properties"), G_CALLBACK (properties_activate) }, 
     { "key-export-file", GTK_STOCK_SAVE_AS, N_("Save Key As..."), "<control><shift>S",
