@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libintl.h>
+#include <config.h>
 #include <gnome.h>
 
 #include "seahorse-widget.h"
@@ -144,8 +144,8 @@ seahorse_keyserver_sync_show (GList *keys)
     
     /* The details message */
     n = g_list_length (keys);
-    t = g_strdup_printf (ngettext ("<b>%d key is selected for syncing</b>", 
-                                   "<b>%d keys are selected for syncing</b>", n), n);
+    t = g_strdup_printf (ngettext ("<b>%d key is selected for synchronizing</b>", 
+                                   "<b>%d keys are selected for synchronizing</b>", n), n);
     
     w = glade_xml_get_widget (swidget->xml, "detail-message");
     g_return_val_if_fail (swidget != NULL, win);
@@ -195,20 +195,23 @@ seahorse_keyserver_sync (GList *keys)
 
     mop = seahorse_multi_operation_new ();
 
-    /* And now syncing keys from the servers */
+    /* And now synchronizing keys from the servers */
     ks = seahorse_gconf_get_string_list (KEYSERVER_KEY);
     ks = seahorse_server_source_purge_keyservers (ks);
     
     for (l = ks; l; l = g_slist_next (l)) {
         
         sksrc = seahorse_context_remote_key_source (SCTX_APP (), (const gchar*)(l->data));
-        g_return_if_fail (sksrc != NULL);
+
+        /* This can happen if the URI scheme is not supported */
+        if (sksrc == NULL)
+            continue;
         
         lsksrc = seahorse_context_find_key_source (SCTX_APP (), 
                         seahorse_key_source_get_ktype (sksrc), SKEY_LOC_LOCAL);
         
         if (lsksrc) {
-            op = seahorse_transfer_operation_new (_("Syncing keys"), sksrc, lsksrc, keyids);
+            op = seahorse_transfer_operation_new (_("Synchronizing keys"), sksrc, lsksrc, keyids);
             g_return_if_fail (op != NULL);
 
             seahorse_multi_operation_take (mop, op);
@@ -223,19 +226,23 @@ seahorse_keyserver_sync (GList *keys)
     if (keyserver && keyserver[0]) {
         
         sksrc = seahorse_context_remote_key_source (SCTX_APP (), keyserver);
-        g_return_if_fail (sksrc != NULL);
-        
-        op = seahorse_context_transfer_keys (SCTX_APP (), keys, sksrc);
-        g_return_if_fail (sksrc != NULL);
 
-        seahorse_multi_operation_take (mop, op);
-        seahorse_operation_watch (op, G_CALLBACK (sync_import_complete), NULL, sksrc);
+        /* This can happen if the URI scheme is not supported */
+        if (sksrc != NULL) {
+
+            op = seahorse_context_transfer_keys (SCTX_APP (), keys, sksrc);
+            g_return_if_fail (sksrc != NULL);
+
+            seahorse_multi_operation_take (mop, op);
+            seahorse_operation_watch (op, G_CALLBACK (sync_import_complete), NULL, sksrc);
+
+        }
     }
 
     g_slist_free (keyids);
     g_free (keyserver);
     
     /* Show the progress window if necessary */
-    seahorse_progress_show (SEAHORSE_OPERATION (mop), _("Syncing keys..."), FALSE);
+    seahorse_progress_show (SEAHORSE_OPERATION (mop), _("Synchronizing keys..."), FALSE);
     g_object_unref (mop);
 }
